@@ -25,6 +25,12 @@
 #include "scale/commons.h"
 
 
+/* heap$B$N?F;R$N%N!<%I$r7W;;$9$k%^%/%m(B */
+#define HEAP_LCHILD_INDEX(parent) (2 * (parent))
+#define HEAP_RCHILD_INDEX(parent) (2 * (parent) + 1)
+#define HEAP_PARENT_INDEX(child)  ((size_t)((child) / 2))
+
+
 typedef struct _sc_heap sheap_t;
 
 
