@@ -16,7 +16,8 @@
  */
 
 /**
-   <p>$B%9%?%C%/9=B$$H0lO"$NA`:n$rDs6!$9$k!#A`:n$NBgH>$O%^%/%m$GDj5A$5$l$F$$$k(B
+   <p>
+   $B%9%?%C%/9=B$$H0lO"$NA`:n$rDs6!$9$k!#A`:n$NBgH>$O%^%/%m$GDj5A$5$l$F$$$k!#(B
    </p>
 */
 
