@@ -55,9 +55,10 @@ svector_t *		s_vector_alloc(void);
 svector_t *		s_vector_allocn(size_t);
 void			s_vector_free(svector_t *);
 size_t			s_vector_size(svector_t *);
+void			s_vector_insert_at(svector_t *, uint, const spointer);
 void			s_vector_add(svector_t *, const spointer);
-spointer		s_vector_get(svector_t *, size_t);
-spointer		s_vector_remove(svector_t *, size_t);
+spointer		s_vector_get(svector_t *, uint);
+spointer		s_vector_remove(svector_t *, uint);
 sint32			s_vector_find(svector_t *, sc_compf_t, spointer);
 sboolean		s_vector_join(svector_t *, svector_t *);
 void			s_vector_sort(svector_t *, sc_compf_t);
