@@ -16,6 +16,13 @@
 /**
  * $BCj>]2DJQD9G[Ns$rI=$9(Bsxarray_t$B$H0lO"$N4X?t!J<B:]$O%^%/%m!K$rDs6!$9$k!#(B
  * sxarray_t$B$O(Bs_list_xarray()$B$d(Bs_vector_xarray()$B$rDL$7$F:n@.$5$l$k!#(B
+ *
+ * sxarray_t$B$K4XO"$7$?A4$F$N4X?t%^%/%m!J5Z$S(Bsxarray_t$B$K4^$^$l$k4X?t%]%$%s%?!K(B
+ * $B$NBh0l0z?t$K$O(B`$BI,$:(B'$B$=$N9=B$BN<+?H$rEO$9$3$H!#$=$l$,!"H~$7$/$J$$0Y!"(B
+ * $B0lHLE*$K$O4X?t%^%/%m$r;HMQ$9$k$3$H$r?d>)$9$k!#(B
+ * 
+ * $B!JNc!K(Bxarr->get(xarr, 1) <--> s_xarray_get(xarr, 1)
+ * $B!JNc!K(Bxarr->add(xarr, p) <--> s_xarray_add(xarr, p)
  */
 
 #ifndef _SCALE_XARRAY_H_
@@ -29,15 +36,16 @@
 typedef struct _sc_xarray sxarray_t;
 
 
-#define s_xarray_free(__xarr) (__xarr->free(__xarr))
-#define s_xarray_size(__xarr) (__xarr->size(__xarr))
-#define s_xarray_add(__xarr, __data) (__xarr->add(__xarr, __data))
-#define s_xarray_get(__xarr, __index) (__xarr->get(__xarr, __index))
-#define s_xarray_remove(__xarr, __index) (__xarr->remove(__xarr, __index))
-#define s_xarray_find(__xarr, __cmpf, __data) \
-(__xarr->find(__xarr, __cmpf, __data))
-#define s_xarray_iterator(__xarr) (__xarr->iterator(__xarr))
-#define s_xarray_sort(__xarr, __cmpf) (_xarr->sort(__xarr))
+#define s_xarray_free(xa) (xa->free(xa))
+#define s_xarray_size(xa) (xa->size(xa))
+#define s_xarray_insert_at(xa, idx, data) (xa->insert_at(xa, idx, data))
+#define s_xarray_add(xa, data) (xa->add(xa, data))
+#define s_xarray_get(xa, idx) (xa->get(xa, idx))
+#define s_xarray_remove(xa, idx) (xa->remove(xa, idx))
+#define s_xarray_find(xa, __cmpf, data) (xa->find(xa, __cmpf, data))
+#define s_xarray_iterator(xa) (xa->iterator(xa))
+#define s_xarray_sort(xa, __cmpf) (xa->sort(xa))
+#define s_xarray_join(xd, xs) (xd->join(xd, xs))
 
 
 struct _sc_xarray {
@@ -46,13 +54,15 @@ struct _sc_xarray {
 	/* sxarray interfaces */
 	
 	void		(*free)(sxarray_t *);		
-	size_t		(*size)(sxarray_t *);		
+	size_t		(*size)(sxarray_t *);
+	void		(*insert_at)(sxarray_t *, uint, spointer);
 	void		(*add)(sxarray_t *, spointer); 
-	spointer	(*get)(sxarray_t *, size_t) ;
-	spointer	(*remove)(sxarray_t *, size_t);
+	spointer	(*get)(sxarray_t *, uint) ;
+	spointer	(*remove)(sxarray_t *, uint);
 	sint32		(*find)(sxarray_t *, sc_compf_t, spointer);
 	siterator_t * (*iterator)(sxarray_t *);
 	void		(*sort)(sxarray_t *, sc_compf_t);
+	void		(*join)(sxarray_t *, sxarray_t *);
 
 	/* -- CAUTION ---------------------
 	   Do never touch thing below here.
