@@ -35,7 +35,7 @@ s_hash_alloc(size_t hsize, hashfunc_t hfunc, sc_compf_t cmpf)
 {
 	shash_t *htable;
 
-	htable = s_malloc(sizeof(shash_t));
+	htable = typed_malloc(shash_t);
 	htable->hashsize = (hsize != 0)?hsize:DEFAULT_HASH_SIZE;
 	htable->table = s_calloc(htable->hashsize, sizeof(shash_elt_t *));
 	htable->hash = hfunc;
@@ -69,7 +69,7 @@ s_hash_put(shash_t *htable, spointer key, spointer obj)
 	shash_elt_t *next, *elt;
 	unsigned int hashkey;
 
-	elt = s_malloc(sizeof(shash_elt_t));
+	elt = typed_malloc(shash_elt_t);
 	elt->key = key;
 	elt->obj = obj;
 
@@ -241,13 +241,13 @@ s_hash_keys(shash_t *htable)
 {
 	siterator_t *itr;
 
-	itr = (siterator_t *)s_malloc(sizeof(siterator_t));
+	itr = typed_malloc(siterator_t);
 	itr->listdata = htable;
 	itr->next  = _s_hash_iterator_next;
 	itr->clear = _s_hash_iterator_clear;
 	itr->free  = _s_hash_iterator_free;
 
-	itr->data = (hash_itr_manager_t *)s_malloc(sizeof(hash_itr_manager_t));
+	itr->data = typed_malloc(hash_itr_manager_t);
 
 	itr->clear(itr);
 
