@@ -51,7 +51,7 @@ s_vector_allocn(size_t n)
 {
 	svector_t *vect;
 
-	vect = (svector_t *)s_malloc(sizeof(svector_t));
+	vect = typed_malloc(svector_t);
 	vect->count = 0;
 	vect->memsize = 0;
 	vect->nextidx = 0;
@@ -79,18 +79,33 @@ s_vector_size(svector_t *vect)
 
 
 void
-s_vector_add(svector_t *vect, const spointer contents) 
+s_vector_insert_at(svector_t *vect, uint idx, const spointer contents)
 {
+	int i;
+
 	if (vect->memsize == vect->nextidx)
 		_s_vector_grouth(vect, vect->memsize + DEF_GROUTH_RATIO);
 
-	vect->array[vect->nextidx++] = contents;
+	for (i=vect->count; i>idx; i--) {
+		vect->array[i] = vect->array[i-1];
+	}
+
+	vect->array[idx] = contents;
+
 	++vect->count;
+	++vect->nextidx;
+}
+
+
+void
+s_vector_add(svector_t *vect, const spointer contents) 
+{
+	s_vector_insert_at(vect, vect->count, contents);
 }
 
 
 spointer		
-s_vector_get(svector_t *vect, size_t idx) 
+s_vector_get(svector_t *vect, uint idx) 
 {
 	if (vect->count <= idx)
 		return NULL;
@@ -100,7 +115,7 @@ s_vector_get(svector_t *vect, size_t idx)
 
 
 spointer		
-s_vector_remove(svector_t *vect, size_t idx) 
+s_vector_remove(svector_t *vect, uint idx) 
 {
 	spointer contents;
 	sint i;
@@ -148,8 +163,7 @@ s_vector_join(svector_t *dst, svector_t *src)
 		_s_vector_grouth(dst, newsize);
 
 	for (i=0; i<src->count; i++) {
-		dst->array[dst->nextidx] = src->array[i];
-		++dst->nextidx;
+		dst->array[dst->nextidx++] = src->array[i];
 	}
 
 	dst->count += src->count;
@@ -255,14 +269,13 @@ s_vector_iterator(svector_t *vect)
 {
 	siterator_t *itr;
 
-	itr = (siterator_t *)s_malloc(sizeof(siterator_t));
+	itr = typed_malloc(siterator_t);
 	itr->listdata = vect;
 	itr->next = _s_vector_iterator_next;
 	itr->clear = _s_vector_iterator_clear;
 	itr->free = _s_vector_iterator_free;
-	
-	itr->data = (vector_itr_manager_t *)
-		s_malloc(sizeof(vector_itr_manager_t));
+
+	itr->data = typed_malloc(vector_itr_manager_t);
 
 	itr->clear(itr);
 
@@ -292,56 +305,76 @@ _s_vect_xarr_free(sxarray_t *xarr)
 static size_t
 _s_vect_xarr_size(sxarray_t *xarr)
 {
-	svector_t *vect = __XARR_GET_VECT(xarr);
-	return s_vector_size(vect);
+	return s_vector_size(__XARR_GET_VECT(xarr));
+}
+
+
+static void
+_s_vect_xarr_insert_at(sxarray_t *xarr, uint idx, spointer contents)
+{
+	s_vector_insert_at(__XARR_GET_VECT(xarr), idx, contents);
 }
 
 
 static void
 _s_vect_xarr_add(sxarray_t *xarr, spointer contents)
 {
-	svector_t *vect = __XARR_GET_VECT(xarr);
-	s_vector_add(vect, contents);
+	s_vector_add(__XARR_GET_VECT(xarr), contents);
 }
 
 
 static spointer
 _s_vect_xarr_get(sxarray_t *xarr, size_t ind)
 {
-	svector_t *vect = __XARR_GET_VECT(xarr);
-	return s_vector_get(vect, ind);
+	return s_vector_get(__XARR_GET_VECT(xarr), ind);
 }
 
 
 static spointer
 _s_vect_xarr_remove(sxarray_t *xarr, size_t ind)
 {
-	svector_t *vect = __XARR_GET_VECT(xarr);
-	return s_vector_remove(vect, ind);
+	return s_vector_remove(__XARR_GET_VECT(xarr), ind);
 }
 
 
 static sint32
 _s_vect_xarr_find(sxarray_t *xarr, sc_compf_t cmpf, spointer contents)
 {
-	svector_t *vect = __XARR_GET_VECT(xarr);
-	return s_vector_find(vect, cmpf, contents);
+	return s_vector_find(__XARR_GET_VECT(xarr), cmpf, contents);
 }
 
 
 static siterator_t *
 _s_vect_xarr_iterator(sxarray_t *xarr)
 {
-	svector_t *vect = __XARR_GET_VECT(xarr);
-	return s_vector_iterator(vect);
+	return s_vector_iterator(__XARR_GET_VECT(xarr));
 }
 
 
 static void
 _s_vect_xarr_sort(sxarray_t *xarr, sc_compf_t cmpf)
 {
-	svector_t *vect = __XARR_GET_VECT(xarr);
-	s_vector_sort(vect, cmpf);
+	s_vector_sort(__XARR_GET_VECT(xarr), cmpf);
+}
+
+
+static void
+_s_vect_xarr_join(sxarray_t *dest, sxarray_t *src)
+{
+	svector_t *dvect = __XARR_GET_VECT(dest);
+	size_t newsize, srcsize;
+	uint i;
+
+	srcsize = s_xarray_size(src);
+	if ((newsize = dvect->count + srcsize) > dvect->memsize) {
+		_s_vector_grouth(dvect, newsize);
+	}
+
+	for (i=0; i<srcsize; i++) {
+		dvect->array[dvect->nextidx++] = s_xarray_get(src, i);
+	}
+
+	dvect->count += srcsize;
 }
 
 
@@ -360,16 +393,18 @@ s_vector_attach_xarray(svector_t *vect)
 {
 	sxarray_t *xarr;
 
-	xarr = (sxarray_t *)s_malloc(sizeof(sxarray_t));
+	xarr = typed_malloc(sxarray_t);
 	xarr->listdata = vect;
 	xarr->free     = _s_vect_xarr_free;
 	xarr->size     = _s_vect_xarr_size;
 	xarr->add      = _s_vect_xarr_add;
 	xarr->get      = _s_vect_xarr_get;
 	xarr->remove   = _s_vect_xarr_remove;
-	xarr->find     = _s_vect_xarr_find;
+	xarr->find	   = _s_vect_xarr_find;
 	xarr->iterator = _s_vect_xarr_iterator;
 	xarr->sort     = _s_vect_xarr_sort;
+	xarr->join	   = _s_vect_xarr_join;
+	xarr->insert_at = _s_vect_xarr_insert_at;
 	
 	xarr->is_origin = false;
 
