@@ -40,6 +40,8 @@
 #include "scale/btree.h"
 #include "scale/iterator.h"
 #include "scale/xarray.h"
+#include "scale/graphviz.h"
+
 
 #define FUNC_START() printf("[%s] {\n", __func__)
 #define FUNC_END()   printf("}\n");
@@ -68,12 +70,51 @@ iterator_tester(siterator_t *itr)
 }
 
 
+void
+sxarray_join_test(sxarray_t *dx, sxarray_t *sx)
+{
+	assert(s_xarray_size(dx) == 0);
+	assert(s_xarray_size(sx) == 0);
+
+	s_xarray_add(dx, "A");
+	s_xarray_add(dx, "B");
+	s_xarray_add(dx, "C");
+
+	s_xarray_add(sx, "a");
+	s_xarray_add(sx, "b");
+	s_xarray_add(sx, "c");
+
+	assert(s_xarray_size(dx) == 3);
+	assert(s_xarray_size(sx) == 3);
+
+	s_xarray_join(dx, sx);
+
+	assert(s_xarray_size(dx) == 6);
+
+	assert(strcmp(s_xarray_get(dx, 0), "A") == 0);
+	assert(strcmp(s_xarray_get(dx, 1), "B") == 0);
+	assert(strcmp(s_xarray_get(dx, 2), "C") == 0);
+	assert(strcmp(s_xarray_get(dx, 3), "a") == 0);
+	assert(strcmp(s_xarray_get(dx, 4), "b") == 0);
+	assert(strcmp(s_xarray_get(dx, 5), "c") == 0);
+
+	assert(strcmp(s_xarray_remove(dx, 0), "A") == 0);
+	assert(strcmp(s_xarray_remove(dx, 0), "B") == 0);
+	assert(strcmp(s_xarray_remove(dx, 0), "C") == 0);
+	assert(strcmp(s_xarray_remove(dx, 0), "a") == 0);
+	assert(strcmp(s_xarray_remove(dx, 0), "b") == 0);
+	assert(strcmp(s_xarray_remove(dx, 0), "c") == 0);
+
+	assert(s_xarray_size(dx) == 0);
+}
+
+
 void
 sxarray_tester(sxarray_t *xarr)
 {
-	assert(xarr->size(xarr) == 0);
+	sxarray_t *vx, *lx; /* vector xarray, list xarray */
 
-	printf("\t - sxarray test");
+	assert(xarr->size(xarr) == 0);
 
 	s_xarray_add(xarr, "A");
 	s_xarray_add(xarr, "B");
@@ -91,7 +132,15 @@ sxarray_tester(sxarray_t *xarr)
 	assert(strcmp(s_xarray_remove(xarr, 0), "C") == 0);
 	assert(s_xarray_size(xarr) == 0);
 
-	printf("\t[  O  K  ]\n");
+	/* join test */
+	vx = s_vector_xarray();
+	lx = s_list_xarray();
+
+	sxarray_join_test(xarr, vx);
+	sxarray_join_test(xarr, lx);
+
+	s_xarray_free(vx);
+	s_xarray_free(lx);
 }
 
 
@@ -109,10 +158,22 @@ test_list(void)
 	s_list_add(list, "B");
 	s_list_add(list, "C");
 
-	assert(list->count == 3);
-	assert(strcmp(s_list_get(list, 0), "A") == 0);
-	assert(strcmp(s_list_get(list, 1), "B") == 0);	
-	assert(strcmp(s_list_get(list, 2), "C") == 0);
+	s_list_insert_at(list, 0, "x");
+	s_list_insert_at(list, 2, "y");
+	s_list_insert_at(list, 5, "z");
+
+	assert(list->count == 6);
+	assert(strcmp(s_list_get(list, 0), "x") == 0);
+	assert(strcmp(s_list_get(list, 1), "A") == 0);
+	assert(strcmp(s_list_get(list, 2), "y") == 0);	
+	assert(strcmp(s_list_get(list, 3), "B") == 0);
+	assert(strcmp(s_list_get(list, 4), "C") == 0);
+	assert(strcmp(s_list_get(list, 5), "z") == 0);
+
+
+	assert(strcmp(s_list_remove(list, 5), "z") == 0);
+	assert(strcmp(s_list_remove(list, 2), "y") == 0);
+	assert(strcmp(s_list_remove(list, 0), "x") == 0);
 
 	assert(strcmp(s_list_remove(list, 1), "B") == 0);
 	assert(list->count == 2);
@@ -205,10 +266,21 @@ test_vector(void)
 	s_vector_add(vect, "B");
 	s_vector_add(vect, "C");
 
-	assert(s_vector_size(vect) == 3);
-	assert(strcmp(s_vector_get(vect, 0), "A") == 0);
-	assert(strcmp(s_vector_get(vect, 1), "B") == 0);
-	assert(strcmp(s_vector_get(vect, 2), "C") == 0);
+	s_vector_insert_at(vect, 0, "x");
+	s_vector_insert_at(vect, 2, "y");
+	s_vector_insert_at(vect, 5, "z");
+
+	assert(s_vector_size(vect) == 6);
+	assert(strcmp(s_vector_get(vect, 0), "x") == 0);
+	assert(strcmp(s_vector_get(vect, 1), "A") == 0);
+	assert(strcmp(s_vector_get(vect, 2), "y") == 0);
+	assert(strcmp(s_vector_get(vect, 3), "B") == 0);
+	assert(strcmp(s_vector_get(vect, 4), "C") == 0);
+	assert(strcmp(s_vector_get(vect, 5), "z") == 0);
+
+	assert(strcmp(s_vector_remove(vect, 5), "z") == 0);
+	assert(strcmp(s_vector_remove(vect, 2), "y") == 0);
+	assert(strcmp(s_vector_remove(vect, 0), "x") == 0);	
 
 	assert(s_vector_find(vect, s_string_compare, "A") == 0);
 	assert(s_vector_find(vect, s_string_compare, "B") == 1);
@@ -454,6 +526,11 @@ test_heap()
 	s_heap_push(heap, "E");
 
 	assert(s_heap_size(heap) == 6);
+
+	sbuffer_t *graphbuf = s_heap_graphviz(heap);
+	printf("%s\n", graphbuf->string);
+	s_buffer_free(graphbuf);
+
 	assert(strcmp(s_heap_pop(heap), "F") == 0);
 	assert(strcmp(s_heap_pop(heap), "E") == 0);
 	assert(strcmp(s_heap_pop(heap), "D") == 0);
@@ -480,9 +557,9 @@ test_btree(void)
 	btree = s_btree_alloc(s_string_compare);
 
 	assert(s_btree_size(btree) == 0);
+	s_btree_add(btree, "c", "C");
 	s_btree_add(btree, "a", "A");
 	s_btree_add(btree, "b", "B");
-	s_btree_add(btree, "c", "C");
 	s_btree_add(btree, "d", "D");
 	s_btree_add(btree, "e", "E");
 	assert(s_btree_size(btree) == 5);
@@ -493,6 +570,10 @@ test_btree(void)
 	assert(strcmp(s_btree_get(btree, "d"), "D") == 0);
 	assert(strcmp(s_btree_get(btree, "e"), "E") == 0);
 
+	sbuffer_t *gbuf = s_btree_graphviz(btree);
+	printf("%s\n", gbuf->string);
+	s_buffer_free(gbuf);
+
 	assert(strcmp(s_btree_remove(btree, "a"), "A") == 0);
 	assert(strcmp(s_btree_remove(btree, "b"), "B") == 0);
 	assert(strcmp(s_btree_remove(btree, "c"), "C") == 0);
